<?php

namespace Litepie\Slider\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litepie\Slider\Models\Slider;


class SliderAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Slider $slider, array $request = [])
    {
        $this->model = $slider;

        $function = Str::camel($action);
        event('litepie.slider.slider.action.' . $action . 'ing', [$slider]);
        $data =  $this->$function($slider, $request);
        event('litepie.slider.slider.action.' . $action . 'ed', [$slider]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Slider $slider, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $slider = $slider->create($attributes);
        return $slider;
    }

    public function update(Slider $slider, array $request)
    {
        $attributes = $request;
        $slider->update($attributes);
        return $slider;
    }

    public function destroy(Slider $slider, array $request)
    {
        $slider->delete();
        return $slider;
    }

    public function copy(Slider $slider, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $slider = $slider->replicate();
            $slider->created_at = Carbon::now();
            $slider->save();
            return $slider;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $slider->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $slider;
    }


}
