<?php

namespace Litepie\Slider\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litepie\Slider\Models\Slider;

class SliderPolicy
{


    /**
     * Determine if the given user can view the slider.
     *
     * @param UserPolicyInterface $authUser
     * @param Slider $slider
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Slider $slider)
    {
        if ($authUser->canDo('slider.slider.view') && $authUser->isAdmin()) {
            return true;
        }

        return $slider->user_id == user_id() && $slider->user_type == user_type();
    }

    /**
     * Determine if the given user can create a slider.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('slider.slider.create');
    }

    /**
     * Determine if the given user can update the given slider.
     *
     * @param UserPolicyInterface $authUser
     * @param Slider $slider
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Slider $slider)
    {
        if ($authUser->canDo('slider.slider.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $slider->user_id == user_id() && $slider->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given slider.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Slider $slider)
    {
        return $slider->user_id == user_id() && $slider->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given slider.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Slider $slider)
    {
        if ($authUser->canDo('slider.slider.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given slider.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Slider $slider)
    {
        if ($authUser->canDo('slider.slider.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
